function histogram=extractColorHistogram(img, n, upperBound)
%extractColorHistogram Extracts the color histogram.
%   extractColorHistogram(img) extracts a color histogram with 10 bins per
%   channel.
%
%   extractColorHistogram(img, n) extracts a color histogram with n bins
%   per channel.
%
%   extractColorHistogram(img, n, upperBound) extracts a color histogram 
%   with n bins per channel and upperBound as the threshold for clipped
%   pixels.
%
    if (nargin<3)
        upperBound=255;
        if (nargin<2)
            n=10;
        end
    end
    
    histogram=zeros(n*n*n, 1);
    
    [rows, cols, ~]=size(img);
    
    count=0;
    img=double(img)/upperBound;
    for row=1:rows
        for col=1:cols
            
            p=img(row, col, :);
            
            if (sum(p)~=0 && sum(p==upperBound)==0)
                count=count+1;
                
                idx1=floor(p(1)*n);
                idx2=floor(p(2)*n);
                idx3=floor(p(3)*n);
                if (idx1>=n)
                    idx1=n-1;
                end
                if (idx2>=n)
                    idx2=n-1;
                end
                if (idx3>=n)
                    idx3=n-1;
                end
                
                idx=idx1+idx2*n+idx3*n*n+1;
                histogram(idx)=histogram(idx)+1;
                
            end
            
        end
    end
    
    histogram=histogram/count;
    
end
