function estimatedChromaticities=testColorCat(groundTruth, histograms)
    
    groundTruthChromaticities=groundTruth./repmat(sum(groundTruth, 2), 1, 3);
    estimatedChromaticities=zeros(size(groundTruthChromaticities));
    
    histogramsCount=numel(histograms);
    
    %K=10;
    %K=3;
    K=15;
    
    %imagesCount=size(histograms, 1);
    %folds=createFolds(K, size(groundTruth, 1));
    folds=getGreyBallFolds();

    stabilize=1;
    
    for fold=1:K
        disp(strcat(['Fold ', num2str(fold), ':']));

        trainGroundTruthChromaticities=groundTruthChromaticities(folds(fold, :)==0, :);
        testGroundTruthChromaticities=groundTruthChromaticities(folds(fold, :)==1, :);

        trainHistograms=cell(histogramsCount, 1);
        testHistograms=cell(histogramsCount, 1);
        
        for i=1:numel(histograms)
            trainHistograms{i}=histograms{i}(folds(fold, :)==0, :);
            testHistograms{i}=histograms{i}(folds(fold, :)==1, :);
        end

        [histogramsIdx, coeffs, x1, x2, coeff, r, reduction]=trainColorCat(trainGroundTruthChromaticities, trainHistograms);
        dx=x2-x1;
        
        %trainHistograms=trainHistograms{histogramsIdx};
        testHistograms=testHistograms{histogramsIdx};
        
        testHistograms=(coeff\testHistograms')';
        testHistograms=testHistograms(:, 1:reduction)+stabilize;
        
        testY=sum(repmat(r', size(testHistograms, 1), 1).*testHistograms, 2);
        
        testWhole=zeros(size(testGroundTruthChromaticities));

        for i=1:size(testY, 1)
            currentY=testY(i);
            if (currentY<0)
                currentY=0;
            elseif (currentY>1)
                currentY=1;
            end
            currentR=currentY*dx+x1;
            currentB=polyval(coeffs, currentR);
            testWhole(i, :)=[currentR, 1-currentR-currentB, currentB];
        end

        estimatedChromaticities(folds(fold, :)==1, :)=testWhole;

    end

    [minAngle, meanAngle, medianAngle, trimeanAngle, best25, worst25, maxAngle]=calculateErrorStatistics(groundTruthChromaticities, estimatedChromaticities);
    
    fprintf('\n\n');
    disp('ANGULAR ERROR STATISTICS');
    disp('========================');
    
    fprintf('Minimum:   %7.2f\n', minAngle);
    fprintf('Mean:      %7.2f\n', meanAngle);
    fprintf('Median:    %7.2f\n', medianAngle);
    fprintf('Trimean:   %7.2f\n', trimeanAngle);
    fprintf('Best 25%%:  %7.2f\n', best25);
    fprintf('Worst 25%%: %7.2f\n', worst25);
    fprintf('Maximum:   %7.2f\n', maxAngle);

end
