function [bestHistogramsIdx, line, x1, x2, pcaMatrix, r, reduction]=trainColorCat(groundTruthChromaticities, histograms, K)
    
    imagesCount=size(histograms{1}, 1);
    
    if (nargin<3)
        K=5;
    end
    
    histogramsCount=numel(histograms);
    
    histogramsIdcs=1:histogramsCount;
    
    estimatedChromaticities=zeros(size(groundTruthChromaticities));
    
    stabilize=1;
    
    bestReduction=size(histograms, 2);
    
    bestMean=-1;
    bestMedian=-1;
    bestHistogramsIdx=1;
    
    for histogramsIdx=histogramsIdcs
        
        disp(strcat(['Histograms index ', num2str(histogramsIdx), ':']));
        
        reductions=1:size(histograms{histogramsIdx}, 2);

        for currentReduction=reductions
            
            folds=createFolds(K, imagesCount);
            
            for fold=1:K
                
                %disp(strcat(['Subfold ', num2str(fold), ':']));
                
                trainGroundTruthChromaticities=groundTruthChromaticities(folds(fold, :)==0, :);
                testGroundTruthChromaticities=groundTruthChromaticities(folds(fold, :)==1, :);
                
                trainHistograms=histograms{histogramsIdx}(folds(fold, :)==0, :);
                testHistograms=histograms{histogramsIdx}(folds(fold, :)==1, :);
                
                [coeff, ~]=princomp(trainHistograms);
                trainHistograms=(coeff\trainHistograms')';
                trainHistograms=trainHistograms(:, 1:currentReduction)+stabilize;
                
                testHistograms=(coeff\testHistograms')';
                testHistograms=testHistograms(:, 1:currentReduction)+stabilize;
                
                coeffs=polyfit(trainGroundTruthChromaticities(:, 1), trainGroundTruthChromaticities(:, 3), 1);
                x1=min(trainGroundTruthChromaticities(:, 1));
                x2=max(trainGroundTruthChromaticities(:, 1));
                dx=x2-x1;
                
                trainY=(trainGroundTruthChromaticities(:, 1)-x1)/dx;
                
                r=regress(trainY, trainHistograms);
                
                testY=sum(repmat(r', size(testHistograms, 1), 1).*testHistograms, 2);
                
                testWhole=zeros(size(testGroundTruthChromaticities));
                
                for i=1:size(testY, 1)
                    currentY=testY(i);
                    if (currentY<0)
                        currentY=0;
                    elseif (currentY>1)
                        currentY=1;
                    end
                    currentR=currentY*dx+x1;
                    currentB=polyval(coeffs, currentR);
                    testWhole(i, :)=[currentR, 1-currentR-currentB, currentB];
                end
                
                estimatedChromaticities(folds(fold, :)==1, :)=testWhole;
            end   
            
            [~, currentMean, currentMedian, ~, ~, ~, ~]=calculateErrorStatistics(groundTruthChromaticities, estimatedChromaticities);
            if (bestMedian==-1 || currentMedian<bestMedian || (currentMedian==bestMedian && currentMean<bestMean))
                bestMedian=currentMedian;
                bestMean=currentMean;
                bestHistogramsIdx=histogramsIdx;
                bestReduction=currentReduction;
                disp([currentReduction, bestMedian])
            end
        end
    end
    
    reduction=bestReduction;
    [pcaMatrix, ~]=princomp(histograms{bestHistogramsIdx});
    reducedHistograms=(pcaMatrix\histograms{bestHistogramsIdx}')';
    reducedHistograms=reducedHistograms(:, 1:reduction)+stabilize;

    line=polyfit(groundTruthChromaticities(:, 1), groundTruthChromaticities(:, 3), 1);
    x1=min(groundTruthChromaticities(:, 1));
    x2=max(groundTruthChromaticities(:, 1));
    dx=x2-x1;

    trainY=(groundTruthChromaticities(:, 1)-x1)/dx;

    r=regress(trainY, reducedHistograms);    
    
end
